@@ -1,4 +1,5 @@
-from django.utils.translation import ugettext_lazy as _
+from django.conf import settings
+from django.utils.translation import gettext_lazy as _
 from cms.extensions.toolbar import ExtensionToolbar
 from cms.toolbar_pool import toolbar_pool
 from cms.toolbar.items import Break
@@ -6,7 +7,6 @@ from cms.cms_toolbars import PAGE_MENU_SECOND_BREAK
 from cmsplugin_cascade.models import CascadePage
 
 
-@toolbar_pool.register
 class CascadePageToolbar(ExtensionToolbar):
     model = CascadePage
 
@@ -19,3 +19,6 @@ class CascadePageToolbar(ExtensionToolbar):
                 position = current_page_menu.find_first(Break, identifier=PAGE_MENU_SECOND_BREAK)
                 disabled = not self.toolbar.edit_mode_active
                 current_page_menu.add_modal_item(_("Extra Page Fields"), position=position, url=url, disabled=disabled)
+
+if settings.CMSPLUGIN_CASCADE['register_page_editor']:
+    toolbar_pool.register(CascadePageToolbar)
