@@ -1,5 +1,5 @@
 from django.utils.html import format_html
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from cms.plugin_pool import plugin_pool
 
 from cmsplugin_cascade import app_settings
