@@ -1,8 +1,8 @@
 from django.core.exceptions import ValidationError, ObjectDoesNotExist
-from django.forms import models
 from django.forms.fields import CharField
 from django.utils.html import format_html
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
+
 from entangled.forms import EntangledModelFormMixin
 from cmsplugin_cascade import app_settings
 from cmsplugin_cascade.models import CascadePage
@@ -42,7 +42,7 @@ class SectionFormMixin(EntangledModelFormMixin):
                         raise ValidationError(msg.format(element_id))
 
 
-class SectionModelMixin(object):
+class SectionModelMixin:
     def element_id(self):
         id_attr = self.glossary.get('element_id')
         if id_attr:
@@ -58,7 +58,7 @@ class SectionModelMixin(object):
         super().delete(*args, **kwargs)
 
 
-class SectionMixin(object):
+class SectionMixin:
     def get_form(self, request, obj=None, **kwargs):
         form = kwargs.get('form', self.form)
         assert issubclass(form, EntangledModelFormMixin), "Form must inherit from EntangledModelFormMixin"
