@@ -1,5 +1,5 @@
 from django.forms import widgets, CharField, ModelChoiceField
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from cmsplugin_cascade.models import IconFont
 from entangled.forms import EntangledModelFormMixin
 
@@ -30,5 +30,6 @@ class IconFormMixin(EntangledModelFormMixin):
         if not getattr(self, 'require_icon', True):
             self.declared_fields['icon_font'].required = False
             self.declared_fields['icon_font'].empty_label = _("No Icon")
+            self.declared_fields['icon_font'].initial = None
             self.declared_fields['symbol'].required = False
         super().__init__(*args, **kwargs)
