@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from cmsplugin_cascade.models import CascadeModelBase
 from cmsplugin_cascade.plugin_base import fake_proxy_models
 from django.db import migrations
-from django.utils.decorators import classproperty
+from django.utils.functional import classproperty
 
 
 class Migration(migrations.Migration):
