@@ -2,13 +2,15 @@ import json
 import os
 import shutil
 from collections import OrderedDict
+from urllib.parse import urljoin
+
 from django.conf import settings
+from django.contrib.auth import get_user_model
 from django.contrib.sites.models import Site
 from django.db import models
 from django.utils.functional import cached_property
-from django.utils.six.moves.urllib.parse import urljoin
-from django.utils.translation import ugettext_lazy as _
-from jsonfield.fields import JSONField
+from django.utils.translation import gettext_lazy as _
+
 from filer.fields.file import FilerFileField
 from cms.extensions import PageExtension
 from cms.extensions.extension_pool import extension_pool
@@ -34,7 +36,11 @@ class SharedGlossary(models.Model):
         unique=True,
     )
 
-    glossary = JSONField(null=True, blank=True, default={})
+    glossary = models.JSONField(
+        null=True,
+        blank=True,
+        default=dict,
+    )
 
     class Meta:
         unique_together = ['plugin_type', 'identifier']
@@ -106,7 +112,10 @@ class InlineCascadeElement(models.Model):
         on_delete=models.CASCADE,
     )
 
-    glossary = JSONField(blank=True, default={})
+    glossary = models.JSONField(
+        blank=True,
+        default=dict,
+    )
 
     class Meta:
         db_table = 'cmsplugin_cascade_inline'
@@ -119,9 +128,9 @@ class SortableInlineCascadeElement(models.Model):
         on_delete=models.CASCADE,
     )
 
-    glossary = JSONField(
+    glossary = models.JSONField(
         blank=True,
-        default={},
+        default=dict,
     )
 
     order = models.PositiveIntegerField(
@@ -156,16 +165,16 @@ class PluginExtraFields(models.Model):
 
     allow_id_tag = models.BooleanField(default=False)
 
-    css_classes = JSONField(
+    css_classes = models.JSONField(
         null=True,
         blank=True,
-        default={},
+        default=dict,
     )
 
-    inline_styles = JSONField(
+    inline_styles = models.JSONField(
         null=True,
         blank=True,
-        default={},
+        default=dict,
     )
 
     class Meta:
@@ -229,10 +238,31 @@ class CascadeClipboard(models.Model):
         unique=True,
     )
 
-    data = JSONField(
+    data = models.JSONField(
         null=True,
         blank=True,
-        default={},
+        default=dict,
+    )
+
+    created_by = models.ForeignKey(
+        get_user_model(),
+        verbose_name=_("Created by"),
+        on_delete=models.SET_NULL,
+        editable=False,
+        null=True,
+    )
+
+    created_at = models.DateTimeField(
+        _("Created at"),
+        auto_now_add=True,
+        editable=False,
+    )
+
+    last_accessed_at = models.DateTimeField(
+        _("Last accessed at"),
+        null=True,
+        default=None,
+        editable=False,
     )
 
     class Meta:
@@ -269,7 +299,7 @@ class IconFont(models.Model):
         help_text=_("A unique identifier to distinguish this icon font."),
     )
 
-    config_data = JSONField()
+    config_data = models.JSONField()
 
     zip_file = FilerFileField(
         on_delete=models.CASCADE,
@@ -334,15 +364,15 @@ class CascadePage(PageExtension):
     """
     Keep arbitrary data tightly coupled to the CMS page.
     """
-    settings = JSONField(
+    settings = models.JSONField(
         blank=True,
-        default={},
+        default=dict,
         help_text=_("User editable settings for this page."),
     )
 
-    glossary = JSONField(
+    glossary = models.JSONField(
         blank=True,
-        default={},
+        default=dict,
         help_text=_("Store for arbitrary page data."),
     )
 
