@@ -1,6 +1,6 @@
 from django.core.exceptions import ValidationError
 from django.forms.fields import CharField, ChoiceField
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils.html import format_html
 from django.utils.text import unescape_entities
 from django.template import engines, TemplateSyntaxError, Template as DjangoTemplate, Context as TemplateContext
