@@ -1,16 +1,15 @@
-from django import VERSION as DJANGO_VERSION
-from django.conf.urls import url
 from django.contrib import admin
 from django.contrib.auth import get_user_model
 from django.http import HttpResponse, HttpResponseBadRequest
 from django.template.response import TemplateResponse
-from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _, ungettext
+from django.urls import reverse, re_path
+from django.utils.translation import gettext_lazy as _, ngettext
 from django.utils.html import format_html
+
 from cms.constants import REFRESH_PAGE
 
 
-class SegmentPluginModelMixin(object):
+class SegmentPluginModelMixin:
     """
     TODO: whenever cmsplugin_cascade drops support for django-CMS < 3.4, this mixin class
     shall be added to the plugin rather than to the model
@@ -48,7 +47,7 @@ class EmulateUserModelMixin(SegmentPluginModelMixin):
         return context_override
 
 
-class EmulateUserAdminMixin(object):
+class EmulateUserAdminMixin:
     UserModel = get_user_model()
 
     @staticmethod
@@ -68,9 +67,9 @@ class EmulateUserAdminMixin(object):
 
     def get_urls(self):
         return [
-            url(r'^emulate_users/$', self.admin_site.admin_view(self.emulate_users), name='emulate-users'),
-            url(r'^emulate_user/(?P<user_id>\d+)/$', self.admin_site.admin_view(self.emulate_user), name='emulate-user'),
-            url(r'^clear_emulations/$', self.admin_site.admin_view(self.clear_emulations), name='clear-emulations'),
+            re_path(r'^emulate_users/$', self.admin_site.admin_view(self.emulate_users), name='emulate-users'),
+            re_path(r'^emulate_user/(?P<user_id>\d+)/$', self.admin_site.admin_view(self.emulate_user), name='emulate-user'),
+            re_path(r'^clear_emulations/$', self.admin_site.admin_view(self.clear_emulations), name='clear-emulations'),
         ] + super().get_urls()
 
     def emulate_user(self, request, user_id):
@@ -119,27 +118,17 @@ class EmulateUserAdminMixin(object):
         self.display_as_link = display_as_link
 
         ChangeList = self.get_changelist(request)
-        if DJANGO_VERSION < (2, 1):
-            cl = ChangeList(request, self.UserModel, list_display,
-                (None,),  # disable list_display_links in ChangeList, instead override that field
-                user_model_admin.list_filter,
-                user_model_admin.date_hierarchy, user_model_admin.search_fields,
-                user_model_admin.list_select_related, user_model_admin.list_per_page,
-                user_model_admin.list_max_show_all,
-                (),  # disable list_editable
-                self)
-        else:
-            cl = ChangeList(request, self.UserModel, list_display,
-                (None,),  # disable list_display_links in ChangeList, instead override that field
-                user_model_admin.list_filter,
-                user_model_admin.date_hierarchy, user_model_admin.search_fields,
-                user_model_admin.list_select_related, user_model_admin.list_per_page,
-                user_model_admin.list_max_show_all,
-                (),  # disable list_editable
-                self,
-                None)
+        cl = ChangeList(request, self.UserModel, list_display,
+            (None,),  # disable list_display_links in ChangeList, instead override that field
+            user_model_admin.list_filter,
+            user_model_admin.date_hierarchy, user_model_admin.search_fields,
+            user_model_admin.list_select_related, user_model_admin.list_per_page,
+            user_model_admin.list_max_show_all,
+            (),  # disable list_editable
+            self,
+            None)
         cl.formset = None
-        selection_note_all = ungettext('%(total_count)s selected',
+        selection_note_all = ngettext('%(total_count)s selected',
             'All %(total_count)s selected', cl.result_count)
 
         context = {
