@@ -2,10 +2,8 @@
 django.jQuery(function($) {
 	'use strict';
 
-	var PicturePlugin, base_plugins = eval(django.cascade.base_plugins);
-
 	// create class handling the client-side part of PicturePlugin
-	PicturePlugin = ring.create(base_plugins, {
+	django.cascade.PicturePlugin = ring.create(eval(django.cascade.ring_plugin_bases.PicturePlugin), {
 		constructor: function() {
 			this.$super();
 
@@ -13,5 +11,4 @@ django.jQuery(function($) {
 			$('.glossary-widget .glossary_target').before($('.form-row.field-link_type'));
 		}
 	});
-	new PicturePlugin();
 });
