@@ -1,12 +1,13 @@
 import re
+from html.parser import HTMLParser
 import json
 import warnings
+
 from django.core.exceptions import ValidationError
 from django.contrib.staticfiles.finders import find
 from django.forms import Media, widgets
 from django.utils.html import escape, format_html, format_html_join
-from six.moves.html_parser import HTMLParser
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class JSONMultiWidget(widgets.MultiWidget):
@@ -99,7 +100,7 @@ class NumberInputWidget(widgets.NumberInput):
             raise ValidationError(self.invalid_message, code='invalid', params={'value': value})
 
 
-class AColorPickerMixin(object):
+class AColorPickerMixin:
     acolorpicker_js = 'node_modules/a-color-picker/dist/acolorpicker.js'
 
     def __init__(self, with_alpha, *args, **kwargs):
@@ -142,9 +143,8 @@ class ColorPickerWidget(AColorPickerMixin, widgets.MultiWidget):
         ]
         super().__init__(with_alpha, widget_list)
 
-    @property
-    def media(self):
-        return super().media + Media(css={'all': ['cascade/css/admin/colorpicker.css']})
+    class Media:
+        css = {'all': ['cascade/css/admin/colorpicker.css']}
 
     def decompress(self, values):
         assert isinstance(values, (list, tuple)), "Values to decompress are kept as lists in JSON"
